@@ -43,7 +43,7 @@ else:
 # `declare_component` and call it done. The wrapper allows us to customize
 # our component's API: we can pre-process its input args, post-process its
 # output value, and add a docstring for users.
-def text_highlighter(text='Hello world!', annotations=[], labels=['PERSON', 'ORG'], colors=None, key=None):
+def text_highlighter(text='Hello world!', selected_label=None, annotations=[], labels=['PERSON', 'ORG'], colors=None, key=None, show_label_selector=True):
     """Create a new instance of "text_highlighter".
 
     Parameters
@@ -66,6 +66,8 @@ def text_highlighter(text='Hello world!', annotations=[], labels=['PERSON', 'ORG
     """
     if type(labels) == str:
         labels = [labels]
+    if selected_label is None:
+        selected_label = labels[0]
     if colors is not None:
         assert len(colors) == len(labels), "Colors and labels must be the same length"
     else:
@@ -77,7 +79,7 @@ def text_highlighter(text='Hello world!', annotations=[], labels=['PERSON', 'ORG
     #
     # "default" is a special argument that specifies the initial return
     # value of the component before the user has interacted with it.
-    component_value = _component_func(text=text, annotations=annotations, colors=colors, labels=labels, key=key, default=annotations)
+    component_value = _component_func(text=text, annotations=annotations, colors=colors, labels=labels, key=key, default=annotations, selected_label=selected_label, show_label_selector=show_label_selector)
 
     # We could modify the value returned from the component if we wanted.
     # There's no need to do this in our simple example - but it's an option.
@@ -103,6 +105,7 @@ if not _RELEASE:
             "color": "red"
         }
     ]
-    value = text_highlighter(text='Hello world! This is a demo.', annotations=annotations, labels='PERSON')
-    st.write(value)
+    label = st.selectbox('Select a label', ['PERSON', 'ORG'])
+    annotations = text_highlighter(text='Hello world! This is a demo. Second line', annotations=annotations, selected_label=label, show_label_selector=False)
+    st.write(annotations)
     
\ No newline at end of file
